@@ -14,6 +14,7 @@ __doc__ = InceptionResnetModelDefinition.create_docs()
 
 class InceptionResnet2Vec(BaseImage2Vec):
     definition = InceptionResnetModelDefinition
+    urls = {"https://tfhub.dev/google/imagenet/inception_resnet_v2/feature_vector/4": {"vector_length": 1536}}
     def __init__(self, model_url="https://tfhub.dev/google/imagenet/inception_resnet_v2/feature_vector/4"):
         self.model_url = model_url
         self.model_name = self.model_url.replace(
@@ -21,12 +22,6 @@ class InceptionResnet2Vec(BaseImage2Vec):
         self.model = hub.load(self.model_url)
         self.vector_length = 1536
 
-    @property
-    def urls(self):
-        return {
-            "https://tfhub.dev/google/imagenet/inception_resnet_v2/feature_vector/4": {"vector_length": 1536}
-        }
-
     @catch_vector_errors
     def encode(self, image):
         """
