@@ -20,19 +20,14 @@ __doc__ = InceptionModelDefinition.create_docs()
 
 class InceptionV12Vec(BaseImage2Vec):
     definition = InceptionModelDefinition
+    urls = {
+           'https://tfhub.dev/google/imagenet/inception_v1/feature_vector/4': {'vector_length': 1024}
+        }
+
     def __init__(self, model_url: str = 'https://tfhub.dev/google/imagenet/inception_v1/feature_vector/4'):
         self.init(model_url)
         self.vector_length = 1024
     
-    @property
-    def urls(self):
-        """
-        URLs and their vector lengths.
-        """
-        return {
-           'https://tfhub.dev/google/imagenet/inception_v1/feature_vector/4': {'vector_length': 1024}
-        }
-
     def init(self, model_url: str):
         self.model_url = model_url
         self.model_name = self.model_url.replace(
